package ffmpegconverter.streams;

/**
 * An object representation of a subtitle stream in a media file
 */
public class SubtitleStream extends StreamObject {
    private String language;
    private String title; //Title shown
    private boolean isFullSubtitle; //Songs and signs will be false
    private boolean isImageSubtitle;

    public SubtitleStream(String codecName, int absoluteIndex, int relativeIndex, String language, String title) {
        this.codecType = "subtitle";
        this.codecName = codecName;
        this.absoluteIndex = absoluteIndex;
        this.language = language;
        this.title = title;
        this.isFullSubtitle = isFullSubtitle();
        this.relativeIndex = relativeIndex;
        this.isImageSubtitle = isImageSubtitle();
    }

    /**
     * Checks whether a subtitle is image based (as opposed to text based)
     * @return True if the subtitle is image based
     */
    private boolean isImageSubtitle() {
        return codecName != null && getCodecName().equals("hdmv_pgs_subtitle");
    }

    /**
     * Checks whether translates everything (as opposed to just songs and signs)
     * @return True if the subtitles translate everything
     */
    private boolean isFullSubtitle() {
        if (getTitle() == null) {
            return false;
        }
        String title = getTitle().toLowerCase();
        return !(title.contains("songs and signs") || title.contains("songs & signs") || title.contains("songs ") ||
                title.contains("signs/songs") || title.contains("[forced]") || title.contains("(forced)"));
    }

    public String getLanguage() {
        return this.language;
    }

    public String getTitle() {
        return this.title;
    }

    public boolean getIsImageSubtitle() {
        return this.isImageSubtitle;
    }

    public boolean getIsFullSubtitle() {
        return this.isFullSubtitle;
    }
}